==> haskell-wl-pprint-extras-3.5.0.5-13-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-extras
version: 3.5.0.5
id: wl-pprint-extras-3.5.0.5-2i15GjbxLFo9jETkGUGY9e
key: wl-pprint-extras-3.5.0.5-2i15GjbxLFo9jETkGUGY9e
license: BSD3
copyright: Copyright (C) 2011-2012 Edward A. Kmett,
           Copyright (C) 2000 Daan Leijen
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-extras/
synopsis: A free monad based on the Wadler/Leijen pretty printer
description:
    A free monad based on the Wadler/Leijen pretty printer
category: Control, Monads, Text
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
abi: a62f2aed990dda9de3f08abe2175e8c8
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/wl-pprint-extras-3.5.0.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/wl-pprint-extras-3.5.0.5
hs-libraries: HSwl-pprint-extras-3.5.0.5-2i15GjbxLFo9jETkGUGY9e
depends:
    base-4.9.1.0 containers-0.5.7.1
    semigroupoids-5.2-I9hFsiKk7FC4Vp6kTTs0M3
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-extras-3.5.0.5-16-i686.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-extras
version: 3.5.0.5
id: wl-pprint-extras-3.5.0.5-AEQOKEgrKhWFuGxlUxh0v1
key: wl-pprint-extras-3.5.0.5-AEQOKEgrKhWFuGxlUxh0v1
license: BSD3
copyright: Copyright (C) 2011-2012 Edward A. Kmett,
           Copyright (C) 2000 Daan Leijen
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-extras/
synopsis: A free monad based on the Wadler/Leijen pretty printer
description:
    A free monad based on the Wadler/Leijen pretty printer
category: Control, Monads, Text
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
abi: bc5e5c03cca74e25d5976930b7e6b6fd
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/wl-pprint-extras-3.5.0.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/wl-pprint-extras-3.5.0.5
hs-libraries: HSwl-pprint-extras-3.5.0.5-AEQOKEgrKhWFuGxlUxh0v1
depends:
    base-4.9.1.0 containers-0.5.7.1
    semigroupoids-5.2.1-5FkqrM8Y49T6SPr4eeeHyr
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
